# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_speak_ended import CallSpeakEnded

__all__ = ["CallSpeakEndedWebhookEvent"]


class CallSpeakEndedWebhookEvent(BaseModel):
    data: Optional[CallSpeakEnded] = None
