# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference_ended import ConferenceEnded

__all__ = ["ConferenceEndedWebhookEvent"]


class ConferenceEndedWebhookEvent(BaseModel):
    data: Optional[ConferenceEnded] = None
