# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal, TypeAlias

__all__ = ["EncryptedMedia"]

EncryptedMedia: TypeAlias = Optional[Literal["SRTP"]]
